@@ -39,13 +39,16 @@ struct bmp_header {
 enum lis_error lis_bmp2scan_params(
 	const void *bmp,
 	size_t *header_size,
-	struct lis_scan_parameters *params
+	struct lis_scan_parameters *params,
+	int *depth,
+	unsigned int *nb_colors_in_palette
 );
 
 
 void lis_scan_params2bmp(
 	const struct lis_scan_parameters *params,
-	void *header
+	void *header,
+	int nb_bits_per_pixels
 );
 
 #endif
